<?php

namespace Drupal\outline;

use Drupal\Core\Config\Entity\ConfigEntityInterface;

/**
 * Provides an interface defining an outline entity.
 */
interface OutlineInterface extends ConfigEntityInterface {

  /**
   * Returns the outline description.
   *
   * @return string
   *   The outline description.
   */
  public function getDescription();

  /**
   * Returns default method of rendering outline entries.
   *
   * @return string
   *   The render method.
   */
  public function getRender();

  /**
   * Sets the default method of rendering outline entries.
   *
   * @param string $render
   *   The render method.
   */
  public function setRender($render);

  /**
   * Returns render name.
   *
   * @return string
   *   The render name.
   */
  public function getRenderName();

  /**
   * Returns the number of tree levels to expand.
   *
   * @return integer
   *   The outline expansion depth.
   */
  public function getExpandLevels();

  /**
   * Sets the default tree expansion depth.
   *
   * @param integer $expand_levels
   *   The number of tree levels to expand.
   */
  public function setExpandLevels($expand_levels);

  /**
   * Hide name field.
   *
   * @return bool
   *   True if the name field should be hidden.
   */
  public function getHideName();

  /**
   * Show or hide the name field.
   *
   * @param boolean $hideName
   *   True if the name field should be hidden.
   */
  public function setHideName($hideName);

  /**
   * Returns the root entry id.
   *
   * @return integer
   *   The root entry id.
   */
  public function getRootEntryId();

  /**
   * Sets the root entry id.
   *
   * @param integer $expand
   *   The root entry id.
   */
  public function setRootEntryId($expand);

  /**
   * Returns the root entry.
   *
   * @return \Drupal\outline\EntryInterface
   *   The root entry.
   */
  public function getRootEntry();

/**
   * Returns the outline directory.
   *
   * @return \Drupal\outline\OutlineInterface
   *   Get the outline directory.
   */
  public static function getOutlineDirectory();

  /**
   * Get the top level entries.
   *
   * @return array
   *   The top level entries.
   */
  public function getTopLevelEntries();

}
