<?php

namespace Drupal\outline;

use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Entity\EntityManagerInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides dynamic permissions of the outline module.
 *
 * @see outline.permissions.yml
 */
class OutlinePermissions implements ContainerInjectionInterface {

  use StringTranslationTrait;

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Constructs an OutlinePermissions instance.
   *
   * @param EntityTypeManagerInterface $entity_type_manager
   *   The entity manager.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager) {
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static($container->get('entity_type.manager'));
  }

  /**
   * Get outline permissions.
   *
   * @return array
   *   Permissions array.
   */
  public function permissions() {
    $permissions = [];
    foreach ($this->entityTypeManager->getStorage('outline')->loadMultiple() as $outline) {
      $permissions += [
        'edit entries in ' . $outline->id() => [
          'title' => $this->t('Edit entries in %outline', ['%outline' => $outline->label()]),
        ],
      ];
      $permissions += [
        'delete entries in ' . $outline->id() => [
          'title' => $this->t('Delete entries from %outline', ['%outline' => $outline->label()]),
        ],
      ];
    }
    return $permissions;
  }

}
